==> rocm-clr-6.3.3.tar.gz: clr-rocm-6.3.3/opencl/tests/ocltst/module/perf/OCLPerfSVMMemcpy.h <==
/* Copyright (c) 2010 - 2021 Advanced Micro Devices, Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE. */

#ifndef _OCL_PERF_SVM_MEMCPY_H_
#define _OCL_PERF_SVM_MEMCPY_H_

#include "OCLTestImp.h"

class OCLPerfSVMMemcpy : public OCLTestImp {
 public:
  OCLPerfSVMMemcpy();
  virtual ~OCLPerfSVMMemcpy();

 public:
  virtual void open(unsigned int test, char* units, double& conversion,
                    unsigned int deviceID);
  virtual void run(void);
  virtual unsigned int close(void);

 private:
  bool failed_;
  unsigned int testSize_;
  unsigned int testSrcFlag_;
  unsigned int testDstFlag_;
  unsigned int testFGFlag_;
  bool FGSystem_;
  bool skip_;
};

#endif  // _OCL_PERF_SVM_MEMCPY_H_

==> rocm-clr-7.1.0.tar.gz: clr-rocm-7.1.0/opencl/tests/ocltst/module/perf/OCLPerfSVMMemcpy.h <==
/* Copyright (c) 2010 - 2021 Advanced Micro Devices, Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE. */

#ifndef _OCL_PERF_SVM_MEMCPY_H_
#define _OCL_PERF_SVM_MEMCPY_H_

#include "OCLTestImp.h"

class OCLPerfSVMMemcpy : public OCLTestImp {
 public:
  OCLPerfSVMMemcpy();
  virtual ~OCLPerfSVMMemcpy();

 public:
  virtual void open(unsigned int test, char* units, double& conversion, unsigned int deviceID);
  virtual void run(void);
  virtual unsigned int close(void);

 private:
  bool failed_;
  unsigned int testSize_;
  unsigned int testSrcFlag_;
  unsigned int testDstFlag_;
  unsigned int testFGFlag_;
  bool FGSystem_;
  bool skip_;
};

#endif  // _OCL_PERF_SVM_MEMCPY_H_
